Re: [O] Some internal libraries still depend on org-bbdb and org-bibtex

2019-04-20 Thread Kyle Meyer
Jonas Bernoulli  writes:

> In 499c0a50cc4b11e37b91374af23cb27ab8fc20d2 some libraries were
> renamed, but some other libraries continue to depend on the old
> features:
>
> - lisp/ox-icalendar.el still depends on org-bbdb
> - contrib/lisp/org-bibtex-extras.el still depends on org-bibtex

Thanks.  Updated in b0add090c.

-- 
Kyle



Re: [O] Tracking time from one state to another?

2019-04-20 Thread Julius Dittmar
Hi Marcin,

Am 19.04.19 um 06:37 schrieb Marcin Borkowski:
> Are those :LOGBOOK: drawers real?  They are not sorted chronologically,
> as they probably should be (though I'm not sure, I don't se them much).

They are. With the newest entry at the top.

Yours,
Julius




[O] Some internal libraries still depend on org-bbdb and org-bibtex

2019-04-20 Thread Jonas Bernoulli
Hello

In 499c0a50cc4b11e37b91374af23cb27ab8fc20d2 some libraries were
renamed, but some other libraries continue to depend on the old
features:

- lisp/ox-icalendar.el still depends on org-bbdb
- contrib/lisp/org-bibtex-extras.el still depends on org-bibtex

Overall this change did not cause too much work for third-parties
I think.  I have opened issues for all the packages known to the
Emacsmirror that still depend on the old features:

- https://github.com/ruediger/bibeltex/issues/2
- https://github.com/andras-simonyi/citeproc-el/issues/7
- https://github.com/unhammer/gnus-recent/issues/13
- https://github.com/seanohalpin/org-link-minor-mode/issues/7
- https://github.com/aki2o/org-linkany/issues/4
- https://github.com/claviclaws/org-mac-protocol/issues/8
- https://github.com/jkitchin/org-ref/issues/649

Cheers,
Jonas



[O] Orgmode Latex Export with Babel/LilyPond

2019-04-20 Thread Jakob Schöttl

Hi,

I'm trying (second attempt), to setup orgmode to export PDFs with images 
generated by Babel/LilyPond.


I followed the setup instructions here:

https://orgmode.org/worg/org-contrib/babel/languages/ob-doc-lilypond.html

I have

a recent emacs (Arch Linux),

~/.emacs file with

(org-babel-do-load-languages
  'org-babel-load-languages
  '((lilypond t)))

(although I saw many other snippets where there is a "." between the 
(lilypond t)). I tried both variants.


I tried also tried (require 'lilypond) instead 
org-babel-do-load-languages which caused an error.


I pressed C-c C-e l p -> "PDF file produced."

But no images are generated and no images appear in the PDF. Only plain 
source code.


Any ideas?
Thank you!

- Jakob




[O] [PATCH] Feature proposal : support "scale=" includegraphics option in the builtin latex exporter.

2019-04-20 Thread Emmanuel Charpentier
Attached is my proposal for the feature I suggested. My quick tests
pass[1]. Better tests by someone knowledgeable in graphics would be 
useful, as well as a test in the test suite.

HTH,

--
Emmanuel Charpentier

[1] I get unrelated failures from "make test" :
4 unexpected results:
   FAILED  test-org-clock/clocktable/extend-today-until
   FAILED  test-org-clock/clocktable/step
   FAILED  test-org/timestamp-from-string
   FAILED  test-org/timestamp-from-time

I can't see any link with my proposal. BTW, I get the same failures
from the unmodified master branch (fetched this morning...).

Le vendredi 19 avril 2019 à 09:27 +0200, Emmanuel Charpentier a écrit :
> Dear list,
> 
> Most graphics-able exporters support some form of a scale parameter,
> sizing the resultant image as a function of the original graphics
> file
> (intended) size.
> 
> This is true for:
>   * built-in ODT exporter
>   * ox-pandoc Latex/ODT/DOCX exporters.
> 
> This possibility comes handy to avoid (or at least master) the side
> effects of scaling (fonts amplification, /reduction, bitmap
> fuzinness,
> etc...).
> 
> It should be supported on the native LaTeX exporter (and possibly
> "scale: 1" may become the default...).
> 
> In addition (but this is probably a different problem), some
> scaling/sizing mechanism may be implemented for the HTML exporter.
> 
> --
> Emmanuel Charpentier
> 
From 2526a06e4f77a2fdae615a95365f557c40b6d968 Mon Sep 17 00:00:00 2001
From: Emmanuel Charpentier 
Date: Sat, 20 Apr 2019 10:25:24 +0200
Subject: [PATCH] Support a :scale parameter in org-latex-export-to-latex and
 friends

* lisp/ox-latex.el: introduce a :scale #+ATTR_LATEX parameter, as well
as a "" default value for it.  When present, it overrides :width and
:height parameters (as it does for ODT export and in ox-pandoc
exporters) ; therefore, setting a default value for :scale should be
exceptional.

Implementation: uses \scalebox for tikz/pgf images, "scale=" parameter
of \includegraphics in other cases.

* doc/org-manual.org: document the new :scale #+ATTR_LATEX parameter,
---
 doc/org-manual.org |  8 ++--
 lisp/ox-latex.el   | 49 ++
 2 files changed, 42 insertions(+), 15 deletions(-)

diff --git a/doc/org-manual.org b/doc/org-manual.org
index a8f4a45ea..a9114184a 100644
--- a/doc/org-manual.org
+++ b/doc/org-manual.org
@@ -13277,14 +13277,18 @@ insert the image.  But for TikZ (http://sourceforge.net/projects/pgf/)
 images, the back-end uses an ~\input~ macro wrapped within
 a ~tikzpicture~ environment.
 
-For specifying image =:width=, =:height=, and other =:options=, use
-this syntax:
+For specifying image =:width=, =:height=, =:scale= and other =:options=,
+use this syntax:
 
 #+begin_example
 ,#+ATTR_LATEX: :width 5cm :options angle=90
 [[./img/sed-hr4049.pdf]]
 #+end_example
 
+A =:scale= parameter overrides both =:width= and =:height= parameters ;
+therefore, setting its default value should be done only in exceptional
+circumstances.
+
 For custom commands for captions, use the =:caption= attribute.  It
 overrides the default =#+CAPTION= value:
 
diff --git a/lisp/ox-latex.el b/lisp/ox-latex.el
index cdcb07aca..60b8773b0 100644
--- a/lisp/ox-latex.el
+++ b/lisp/ox-latex.el
@@ -127,6 +127,7 @@
 (:latex-format-headline-function nil nil org-latex-format-headline-function)
 (:latex-format-inlinetask-function nil nil org-latex-format-inlinetask-function)
 (:latex-hyperref-template nil nil org-latex-hyperref-template t)
+(:latex-image-default-scale nil nil org-latex-image-default-scale)
 (:latex-image-default-height nil nil org-latex-image-default-height)
 (:latex-image-default-option nil nil org-latex-image-default-option)
 (:latex-image-default-width nil nil org-latex-image-default-width)
@@ -708,6 +709,17 @@ This value will not be used if a height is provided."
   :package-version '(Org . "8.0")
   :type 'string)
 
+(defcustom org-latex-image-default-scale ""
+  "Default scale for images.
+This value will not be used if a width or a scale is provided,
+or if the image is wrapped within a \"wrapfigure\",environment.
+Since scale overrides width and height, setting its default
+value should be done only in exceptional circumstances."
+  :group 'org-export-latex
+  :version "25.1"
+  :package-version '(Org . "9.2")
+  :type 'string)
+
 (defcustom org-latex-image-default-height ""
   "Default height for images.
 This value will not be used if a width is provided, or if the
@@ -2374,13 +2386,18 @@ used as a communication channel."
 	  (if (plist-member attr :center) (plist-get attr :center)
 	(plist-get info :latex-images-centered)))
 	 (comment-include (if (plist-get attr :comment-include) "%" ""))
-	 ;; It is possible to specify width and height in the
-	 ;; ATTR_LATEX line, and also via default variables.
-	 (width (cond ((plist-get attr :width))
+	 ;; It is possible to specify scale or width and height in
+	 ;; the ATTR_LATEX line, and also via default variables.

Re: [O] Interaction of Agenda with DEADLINE & SCHEDULED

2019-04-20 Thread Ihor Radchenko
Hi,

There seems to be not much interest about this email, so I doubt that
the described functionality will be added to org any time soon.
However, let me try to give you some hints, which might be useful for
your personal config.

> For example, how would one create a custom agenda view that
>
> - shows all accomplished tasks within the DEADLINE last week
> - shows all accomplished tasks that missed the DEADLINE last week
>
> Then does the same for the coming week, i.e.
>
> - show all tasks which are due in the next week, i.e., within the
>   DEADLINE
> - show all tasks which are overdue

There is org-super-agenda package
(https://github.com/alphapapa/org-super-agenda), which already have a
part of the functionality. You can use :scheduled and :deadline
selectors as a starting point to achieve what you want.

A more direct way to approach this is a custom skip function. As a
starting point, see my own skip function for filter todo items with
deadline, but scheduled in future:

#+begin_src emacs-lisp
(defun org-agenda-skip-deadlines-before-schedule ()
  "Skip tasks, with deadline and scheduled in future and tasks without 
deadline."
  (require 'org-agenda)
  (org-with-wide-buffer
   (let* ((tmp-deadline-time (flet ((org-back-to-heading ( args) t)) ; we 
should be at heading already and it consumes too much cpu time otherwise
   (org-get-deadline-time (point
  (tmp-scheduled-time (org-get-scheduled-time (point)))
  (tmp-cur-deadline (time-to-days tmp-deadline-time))
  (tmp-cur-schedule (time-to-days tmp-scheduled-time))
  (tmp-cur-day (time-to-days (apply #'encode-time
(append '(0 0 0)
(list (nth 1 
org-agenda-current-date))
(list (nth 0 
org-agenda-current-date))
(list (nth 2 
org-agenda-current-date)))
 (when (or
(not tmp-deadline-time)
(and
 tmp-scheduled-time
 tmp-deadline-time
 (> tmp-cur-schedule tmp-cur-day)
 ;;(> tmp-cur-deadline tmp-cur-day)
 ))
   (re-search-forward (org-get-limited-outline-regexp) nil 'noerror)
   (point)
#+end_src

> Ideally, the interaction could even be more informational, so for
> example, analysis of the available work time next week (assuming 40
> hours for example) vs. the total estimated effort of all of the above
> tasks, helping to answer the question of whether all tasks are even
> achievable given the amount of available work time.
>
> Another potential -and very valuable- analysis could be a recommendation
> of order given DEADLINE, priority and effort over a period of time, for
> example the next week. What should one do first, then second, etc. to
> maximize output over a given period of time?

What you want here is actually quite a complicated optimization problem,
which probably deserves a separate full project of its own.
I cannot comment much on this part since effort estimates never worked
for me.

Best,
Ihor

Stephan Fabel  writes:

> When creating a custom agenda view, it is often desirable to express a
> relationship between a given task and meaningful dates, such as DEADLINE
> and SCHEDULED. It seems that with org-mode, and especially in the agenda
> view, it is not (yet?) possible to express that.
>
> For example, how would one create a custom agenda view that
>
> - shows all accomplished tasks within the DEADLINE last week
> - shows all accomplished tasks that missed the DEADLINE last week
>
> Then does the same for the coming week, i.e.
>
> - show all tasks which are due in the next week, i.e., within the
>   DEADLINE
> - show all tasks which are overdue
>
> Ideally, the interaction could even be more informational, so for
> example, analysis of the available work time next week (assuming 40
> hours for example) vs. the total estimated effort of all of the above
> tasks, helping to answer the question of whether all tasks are even
> achievable given the amount of available work time.
>
> Another potential -and very valuable- analysis could be a recommendation
> of order given DEADLINE, priority and effort over a period of time, for
> example the next week. What should one do first, then second, etc. to
> maximize output over a given period of time?
>
> I have been looking for a discussion of these type of questions in the
> documentation, worg and other places like EmacsWiki and haven't really
> found anything.
>
> Thanks for any pointers,
>
> Stephan
>
>
>
>


signature.asc
Description: PGP signature